==> content-0.1.1.tgz: package/lib/loader/loadLayout.js <==
const fs = require('fs')
const join = require('path').join

var layoutNames
var layouts = {}

/**
 * Gets the template and styles of the requested content directory.
 * (The script element is not included because only one is allowed
 *  and we create our own based on the file's front-matter.)
 */
module.exports = function (filePath, srcPath, config) {
  if (!layoutNames) layoutNames = getLayouts(config)
  const contentDir = getDir(filePath, srcPath)
  const layoutsPath = join(srcPath, '../layouts/content')
  const layoutName = getLayout(contentDir, layoutNames)

  if (layoutName !== 'default') {
    if (!layouts[layoutName]) {
      layouts[layoutName] =  readFileFromDir(layoutName, layoutsPath)
    }
    return layouts[layoutName]
  } else {
    return `
      <template><section v-html="content"></section></template>
      <style></style>
    `
  }
}

/**
 * Gets the layout of all registered directories.
 */
function getLayouts (config) {
  const layouts = {}
  config.dirs.forEach(data => {
    const dirName = join(data[0] + '/')
    const dirOpts = data[1]
    layouts[dirName] = dirOpts.layout || config.layout
  })
  return layouts
}

/**
 * Retrieves layout of closest registered directory. (Some content
 * may be nested, but not registered.)
 */
function getLayout (dirName, layouts) {
  if (layouts[dirName]) return layouts[dirName]
  else { // get closest dir by finding longest string match
    var closestDir = ''
    Object.keys(layouts).forEach(key => {
      if (dirName.match(key) && closestDir.length < key.length) closestDir = key
    })
    return layouts[closestDir]
  }
}

function readFileFromDir (name, path) {
  const files = fs.readdirSync(path)
  for (i = 0; i < files.length; i++) {
    const fileName = files[i]
    if (fileName.indexOf(name) > -1) {
      return fs.readFileSync(join(path, fileName), 'utf-8')
    }
  }
}

function getDir (filePath, srcPath) {
  return dirName = filePath
    .replace(srcPath, '')   // remove source path
    .replace(/[^\/]*$/, '') // remove file name
}

==> content-0.1.5.tgz: package/lib/loader/loadLayout.js <==
const fs = require('fs')
const join = require('path').join

var layoutNames
var layouts = {}

/**
 * Gets the template and styles of the requested content directory.
 * (The script element is not included because only one is allowed
 *  and we create our own based on the file's front-matter.)
 */
module.exports = function (filePath, config) {
  if (!layoutNames) layoutNames = getLayouts(config)
  const contentDir = getDir(filePath, config.srcPath)
  const layoutsPath = join(config.srcPath, config.layoutDir)
  const layoutName = getLayout(contentDir, layoutNames)

  if (layoutName !== 'default') {
    if (!layouts[layoutName]) {
      layouts[layoutName] =  readFileFromDir(layoutName, layoutsPath)
    }
    return layouts[layoutName]
  } else {
    return `
      <template><section v-html="content"></section></template>
      <style></style>
    `
  }
}

/**
 * Gets the layout of all registered directories.
 */
function getLayouts (config) {
  const layouts = {}
  config.dirs.forEach(data => {
    const dirName = join(data[0] + '/')
    const dirOpts = data[1]
    layouts[dirName] = dirOpts.layout || config.layout
  })
  return layouts
}

/**
 * Retrieves layout of closest registered directory. (Some content
 * may be nested, but not registered.)
 */
function getLayout (dirName, layouts) {
  if (layouts[dirName]) return layouts[dirName]
  else { // get closest dir by finding longest string match
    var closestDir = ''
    Object.keys(layouts).forEach(key => {
      if (dirName.match(key) && closestDir.length < key.length) closestDir = key
    })
    return layouts[closestDir]
  }
}

function readFileFromDir (name, path) {
  const files = fs.readdirSync(path)
  for (i = 0; i < files.length; i++) {
    const fileName = files[i]
    if (fileName.indexOf(name) > -1) {
      return fs.readFileSync(join(path, fileName), 'utf-8')
    }
  }
}

function getDir (filePath, srcPath) {
  return dirName = filePath
    .replace(srcPath, '')   // remove source path
    .replace(/[^\/]*$/, '') // remove file name
}
